==> kotlin-compiler-0.6.602-sources.jar: org/jetbrains/jet/codegen/DefaultParameterValueLoader.java <==
/*
 * Copyright 2010-2013 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.jet.codegen;

import org.jetbrains.asm4.Type;
import org.jetbrains.jet.lang.descriptors.ValueParameterDescriptor;
import org.jetbrains.jet.lang.psi.JetParameter;

import static org.jetbrains.jet.lang.resolve.BindingContextUtils.descriptorToDeclaration;

public interface DefaultParameterValueLoader {

    void putValueOnStack(ValueParameterDescriptor descriptor, ExpressionCodegen codegen);

    DefaultParameterValueLoader DEFAULT = new DefaultParameterValueLoader() {
        @Override
        public void putValueOnStack(
                ValueParameterDescriptor descriptor,
                ExpressionCodegen codegen
        ) {
            JetParameter jetParameter = (JetParameter) descriptorToDeclaration(codegen.getBindingContext(), descriptor);
            assert jetParameter != null;
            Type propertyType = codegen.typeMapper.mapType(descriptor.getType());
            codegen.gen(jetParameter.getDefaultValue(), propertyType);
        }
    };
}

==> kotlin-compiler-0.7.802-sources.jar: org/jetbrains/jet/codegen/DefaultParameterValueLoader.java <==
/*
 * Copyright 2010-2013 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.jet.codegen;

import org.jetbrains.org.objectweb.asm.Type;
import org.jetbrains.jet.lang.descriptors.ValueParameterDescriptor;
import org.jetbrains.jet.lang.psi.JetParameter;

import static org.jetbrains.jet.lang.resolve.BindingContextUtils.descriptorToDeclaration;

public interface DefaultParameterValueLoader {

    void putValueOnStack(ValueParameterDescriptor descriptor, ExpressionCodegen codegen);

    DefaultParameterValueLoader DEFAULT = new DefaultParameterValueLoader() {
        @Override
        public void putValueOnStack(
                ValueParameterDescriptor descriptor,
                ExpressionCodegen codegen
        ) {
            JetParameter jetParameter = (JetParameter) descriptorToDeclaration(codegen.getBindingContext(), descriptor);
            assert jetParameter != null;
            Type propertyType = codegen.typeMapper.mapType(descriptor.getType());
            codegen.gen(jetParameter.getDefaultValue(), propertyType);
        }
    };
}
